@@ -3,7 +3,7 @@
 Open Asset Import Library (assimp)
 ---------------------------------------------------------------------------
 
-Copyright (c) 2006-2015, assimp team
+Copyright (c) 2006-2016, assimp team
 
 All rights reserved.
 
@@ -56,15 +56,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "StandardShapes.h"
 #include "Importer.h"
 
-// We need boost::common_factor to compute the lcm/gcd of a number
-#include <boost/math/common_factor_rt.hpp>
-#include <boost/scoped_ptr.hpp>
-#include "../include/assimp/DefaultLogger.hpp"
-#include "../include/assimp/mesh.h"
-#include "../include/assimp/material.h"
-#include "../include/assimp/scene.h"
-#include "../include/assimp/IOSystem.hpp"
-#include "../include/assimp/postprocess.h"
+// We need MathFunctions.h to compute the lcm/gcd of a number
+#include "MathFunctions.h"
+#include <memory>
+#include <assimp/DefaultLogger.hpp>
+#include <assimp/mesh.h>
+#include <assimp/material.h>
+#include <assimp/scene.h>
+#include <assimp/IOSystem.hpp>
+#include <assimp/postprocess.h>
 
 
 using namespace Assimp;
@@ -196,7 +196,7 @@ void IRRImporter::BuildSkybox(std::vector<aiMesh*>& meshes, std::vector<aiMateri
         aiMaterial* out = ( aiMaterial* ) (*(materials.end()-(6-i)));
 
         aiString s;
-        s.length = ::sprintf( s.data, "SkyboxSide_%u",i );
+        s.length = ::ai_snprintf( s.data, MAXLEN, "SkyboxSide_%u",i );
         out->AddProperty(&s,AI_MATKEY_NAME);
 
         int shading = aiShadingMode_NoShading;
@@ -347,7 +347,7 @@ void IRRImporter::ComputeAnimations(Node* root, aiNode* real, std::vector<aiNode
         if (cur != total-1) {
             // Build a new name - a prefix instead of a suffix because it is
             // easier to check against
-            anim->mNodeName.length = ::sprintf(anim->mNodeName.data,
+            anim->mNodeName.length = ::ai_snprintf(anim->mNodeName.data, MAXLEN,
                 "$INST_DUMMY_%i_%s",total-1,
                 (root->name.length() ? root->name.c_str() : ""));
 
@@ -402,13 +402,13 @@ void IRRImporter::ComputeAnimations(Node* root, aiNode* real, std::vector<aiNode
                 int lcm = 360;
 
                 if (angles[0])
-                    lcm  = boost::math::lcm(lcm,angles[0]);
+                    lcm  = Math::lcm(lcm,angles[0]);
 
                 if (angles[1])
-                    lcm  = boost::math::lcm(lcm,angles[1]);
+                    lcm  = Math::lcm(lcm,angles[1]);
 
                 if (angles[2])
-                    lcm  = boost::math::lcm(lcm,angles[2]);
+                    lcm  = Math::lcm(lcm,angles[2]);
 
                 if (360 == lcm)
                     break;
@@ -902,7 +902,7 @@ void IRRImporter::GenerateGraph(Node* root,aiNode* rootOut ,aiScene* scene,
 void IRRImporter::InternReadFile( const std::string& pFile,
     aiScene* pScene, IOSystem* pIOHandler)
 {
-    boost::scoped_ptr<IOStream> file( pIOHandler->Open( pFile));
+    std::unique_ptr<IOStream> file( pIOHandler->Open( pFile));
 
     // Check whether we can read from the file
     if( file.get() == NULL)
@@ -1372,8 +1372,7 @@ void IRRImporter::InternReadFile( const std::string& pFile,
 
     /*  Now iterate through all cameras and compute their final (horizontal) FOV
      */
-    for (std::vector<aiCamera*>::iterator it = cameras.begin(), end = cameras.end();it != end; ++it)    {
-        aiCamera* cam = *it;
+    for (aiCamera *cam : cameras) {
 
         // screen aspect could be missing
         if (cam->mAspect)   {
