@@ -161,7 +161,8 @@ def try_load_functions(library_path, dll):
     If successful:
         Tuple containing (library_path, 
                           load from filename function,
-                          load from memory function
+                          load from memory function,
+                          export to filename function,
                           release function, 
                           ctypes handle to assimp library)
     '''
@@ -170,6 +171,7 @@ def try_load_functions(library_path, dll):
         load     = dll.aiImportFile
         release  = dll.aiReleaseImport
         load_mem = dll.aiImportFileFromMemory
+        export   = dll.aiExportScene
     except AttributeError:
         #OK, this is a library, but it doesn't have the functions we need
         return None
@@ -178,7 +180,7 @@ def try_load_functions(library_path, dll):
     from .structs import Scene
     load.restype = POINTER(Scene)
     load_mem.restype = POINTER(Scene)
-    return (library_path, load, load_mem, release, dll)
+    return (library_path, load, load_mem, export, release, dll)
 
 def search_library():
     '''
@@ -187,6 +189,7 @@ def search_library():
     
     Returns: tuple, (load from filename function, 
                      load from memory function,
+                     export to filename function,
                      release function, 
                      dll)
     '''
@@ -202,26 +205,27 @@ def search_library():
     candidates = []
     # test every file
     for curfolder in [folder]+additional_dirs:
-        for filename in os.listdir(curfolder):
-            # our minimum requirement for candidates is that
-            # they should contain 'assimp' somewhere in 
-            # their name
-            if filename.lower().find('assimp')==-1 or\
-                os.path.splitext(filename)[-1].lower() not in ext_whitelist:
-                continue
+        if os.path.isdir(curfolder):
+            for filename in os.listdir(curfolder):
+                # our minimum requirement for candidates is that
+                # they should contain 'assimp' somewhere in 
+                # their name
+                if filename.lower().find('assimp')==-1 or\
+                    os.path.splitext(filename)[-1].lower() not in ext_whitelist:
+                    continue
 
-            library_path = os.path.join(curfolder, filename)
-            logger.debug('Try ' + library_path)
-            try:
-                dll = ctypes.cdll.LoadLibrary(library_path)
-            except Exception as e:
-                logger.warning(str(e))
-                # OK, this except is evil. But different OSs will throw different
-                # errors. So just ignore any errors.
-                continue
-            # see if the functions we need are in the dll
-            loaded = try_load_functions(library_path, dll)
-            if loaded: candidates.append(loaded)
+                library_path = os.path.join(curfolder, filename)
+                logger.debug('Try ' + library_path)
+                try:
+                    dll = ctypes.cdll.LoadLibrary(library_path)
+                except Exception as e:
+                    logger.warning(str(e))
+                    # OK, this except is evil. But different OSs will throw different
+                    # errors. So just ignore any errors.
+                    continue
+                # see if the functions we need are in the dll
+                loaded = try_load_functions(library_path, dll)
+                if loaded: candidates.append(loaded)
 
     if not candidates:
         # no library found
